## Install

```sh
pip3 install --user free-disk
```

## Lint

```sh
pip3 install --user pipenv
git clone https://github.com/fphammerle/free-disk.git
cd freesurfer-volume-reader
pipenv run pylint free_disk
```
